VecSortedSet

Struct VecSortedSet 

pub struct VecSortedSet<T>(/* private fields */);
an array-set. very efficient for small sets.

for explanations about the methods, see BTreeSet and Vec.

Implementations

Source

impl<T> VecSortedSet<T>
where T: Ord,

pub fn new() -> Self

pub fn with_capacity(n: usize) -> Self

pub fn capacity(&self) -> usize

pub fn reserve(&mut self, n: usize)

pub fn shrink_to_fit(&mut self)

pub fn clear(&mut self)

pub fn contains<Q>(&self, e: &Q) -> bool
where T: Borrow<Q>, Q: Ord + ?Sized,

O(log(len))

pub fn get<Q>(&self, e: &Q) -> Option<&T>
where T: Borrow<Q>, Q: Ord + ?Sized,

O(log(len))

pub fn get_mut<Q>(&mut self, e: &Q) -> Option<&mut T>
where T: Borrow<Q>, Q: Ord + ?Sized,

O(log(len))

pub fn insert(&mut self, e: T) -> Option<T>

O(log(len)) when e already exists. O(len) for inserting a new element, caused by shifting all elements after it, which can be avoided by always inserting in order.

pub fn remove<Q>(&mut self, e: &Q) -> Option<T>
where T: Borrow<Q>, Q: Ord + ?Sized,

O(log(len)) when e does not exist. O(len) for removing an element, because of the need for shifting all elements after it.

pub fn append(&mut self, other: &mut VecSortedSet<T>)

pub fn reserve_exact(&mut self, n: usize)

pub fn pop(&mut self) -> Option<T>

pub fn truncate(&mut self, n: usize)

pub fn retain<F>(&mut self, f: F)
where F: FnMut(&T) -> bool,

pub fn split_off(&mut self, at: usize) -> VecSortedSet<T>

pub fn is_disjoint(&self, other: &VecSortedSet<T>) -> bool

pub fn is_subset(&self, other: &VecSortedSet<T>) -> bool

pub fn is_superset(&self, other: &VecSortedSet<T>) -> bool

pub fn union<'a>(&'a self, other: &'a VecSortedSet<T>) -> Union<'a, T>

pub fn intersection<'a>( &'a self, other: &'a VecSortedSet<T>, ) -> Intersection<'a, T>

pub fn difference<'a>(&'a self, other: &'a VecSortedSet<T>) -> Difference<'a, T>

pub fn symmetric_difference<'a>( &'a self, other: &'a VecSortedSet<T>, ) -> SymmetricDifference<'a, T>

Source

impl<T> VecSortedSet<T>

pub fn view_content<'a>(&'a self) -> &'a Vec<T>

a view for the underlying vec. &self methods for Vec such as get and split can be accessed through this.

pub fn iter(&self) -> Iter<'_, T>

iterate over the underlying vec.

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool