pub struct VecSortedSet<T>(/* private fields */);Expand description
Implementations
Sourceimpl<T> VecSortedSet<T>where
T: Ord,
impl<T> VecSortedSet<T>where
T: Ord,
pub fn new() -> Self
pub fn with_capacity(n: usize) -> Self
pub fn capacity(&self) -> usize
pub fn reserve(&mut self, n: usize)
pub fn shrink_to_fit(&mut self)
pub fn clear(&mut self)
Sourcepub fn insert(&mut self, e: T) -> Option<T>
pub fn insert(&mut self, e: T) -> Option<T>
O(log(len)) when e already exists. O(len) for inserting a new element,
caused by shifting all elements after it, which can be avoided by always
inserting in order.
Sourcepub fn remove<Q>(&mut self, e: &Q) -> Option<T>
pub fn remove<Q>(&mut self, e: &Q) -> Option<T>
O(log(len)) when e does not exist. O(len) for removing an element,
because of the need for shifting all elements after it.
pub fn append(&mut self, other: &mut VecSortedSet<T>)
pub fn reserve_exact(&mut self, n: usize)
pub fn pop(&mut self) -> Option<T>
pub fn truncate(&mut self, n: usize)
pub fn retain<F>(&mut self, f: F)
pub fn split_off(&mut self, at: usize) -> VecSortedSet<T>
pub fn is_disjoint(&self, other: &VecSortedSet<T>) -> bool
pub fn is_subset(&self, other: &VecSortedSet<T>) -> bool
pub fn is_superset(&self, other: &VecSortedSet<T>) -> bool
pub fn union<'a>(&'a self, other: &'a VecSortedSet<T>) -> Union<'a, T>
pub fn intersection<'a>( &'a self, other: &'a VecSortedSet<T>, ) -> Intersection<'a, T>
pub fn difference<'a>(&'a self, other: &'a VecSortedSet<T>) -> Difference<'a, T>
pub fn symmetric_difference<'a>( &'a self, other: &'a VecSortedSet<T>, ) -> SymmetricDifference<'a, T>
Sourceimpl<T> VecSortedSet<T>
impl<T> VecSortedSet<T>